==> theia-0.1.8.10-py3-none-any.whl: theia/aws/network/apigateway.py <==
import pulumi

from pulumi_aws import apigateway
from pulumi.output import Output

from typing import Optional, Mapping, List
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class APIGatewayRestAPISettings:
    capi_key_source: Optional[str] = None
    binary_media_types: Optional[List[str]] = None
    body: Optional[str] = None
    description: Optional[str] = None
    disable_execute_api_endpoint: Optional[bool] = None
    fail_on_warnings: Optional[bool] = None
    minimum_compression_size: Optional[str] = None
    name: Optional[str] = None
    policy: Optional[str] = None
    put_rest_api_mode: Optional[str] = None


class APIGatewayRestAPI:
    def __new__(
        cls,
        resource_name: str,
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[APIGatewayRestAPISettings] = APIGatewayRestAPISettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> apigateway.RestApi:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        rest_args = apigateway.RestApiArgs(
            capi_key_source=settings.capi_key_source,
            binary_media_types=settings.binary_media_types,
            body=settings.body,
            description=settings.description,
            disable_execute_api_endpoint=settings.disable_execute_api_endpoint,
            fail_on_warnings=settings.fail_on_warnings,
            minimum_compression_size=settings.minimum_compression_size,
            name=settings.name,
            policy=settings.policy,
            put_rest_api_mode=settings.put_rest_api_mode,
            tags=merged_tags,
        )

        rest_api_out = apigateway.RestApi(resource_name, args=rest_args, opts=opts)

        export_values = {
            "id": rest_api_out.id,
            "arn": rest_api_out.arn,
        }

        pulumi.export(f"api_gateway---{resource_name}", export_values)

        return rest_api_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> apigateway.RestApi:
        stack_ref = StackRegistry.get(stack_name=stack)
        rest_api = stack_ref.get_output(name=f"api_gateway---{resource_name}")
        return apigateway.RestApi.get(resource_name=resource_name, id=rest_api["id"])

==> theia-0.1.8.21-py3-none-any.whl: theia/aws/network/apigateway.py <==
import pulumi
import json
import pulumi_aws

from pulumi_aws import apigateway
from pulumi.output import Output

from typing import Optional, Mapping, List
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class APIGatewayRestAPISettings:
    binary_media_types: Optional[List[str]] = None
    body: Optional[str] = None
    description: Optional[str] = None
    disable_execute_api_endpoint: Optional[bool] = None
    fail_on_warnings: Optional[bool] = None
    minimum_compression_size: Optional[str] = None
    name: Optional[str] = None
    policy: Optional[str] = None
    put_rest_api_mode: Optional[str] = None
    add_default_policy: Optional[bool] = False
    initial_stage_name: Optional[str] = None
    stage_variables: Optional[Mapping[str, str]] = None


class APIGatewayRestAPI:
    def __new__(
        cls,
        resource_name: str,
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[APIGatewayRestAPISettings] = APIGatewayRestAPISettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> apigateway.RestApi:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        rest_args = apigateway.RestApiArgs(
            binary_media_types=settings.binary_media_types,
            body=settings.body,
            description=settings.description,
            disable_execute_api_endpoint=settings.disable_execute_api_endpoint,
            fail_on_warnings=settings.fail_on_warnings,
            minimum_compression_size=settings.minimum_compression_size,
            name=settings.name,
            policy=settings.policy,
            put_rest_api_mode=settings.put_rest_api_mode,
            tags=merged_tags,
        )

        rest_api_out = apigateway.RestApi(resource_name, args=rest_args, opts=opts)

        if settings.add_default_policy:
            policy_data = Output.all(rest_api_out.execution_arn).apply(lambda args: APIGatewayRestAPI.add_policy(args[0]))

            apigateway.RestApiPolicy(
                resource_name=f"{resource_name}-gateway-policy",
                rest_api_id=rest_api_out.id,
                policy=policy_data
            )
        
        if settings.initial_stage_name:
            apigateway.Deployment(f"{resource_name}-deployment",
                rest_api=rest_api_out.id,
                stage_name=settings.initial_stage_name,
                variables=settings.stage_variables
            )
        

        export_values = {
            "id": rest_api_out.id,
            "arn": rest_api_out.arn,
        }

        pulumi.export(f"api_gateway---{resource_name}", export_values)

        return rest_api_out

    def add_policy(api_id):
        policy = {
            "Version" : "2012-10-17",
            "Statement" : [ 
                {
                    "Effect" : "Allow",
                    "Principal" : "*",
                    "Action" : "execute-api:Invoke",
                    "Resource" : f"{api_id}/*"
                } 
            ]
        }
        policy_data = json.dumps(policy)

        return policy_data
        

    @staticmethod
    def import_(stack: str, resource_name: str) -> apigateway.RestApi:
        stack_ref = StackRegistry.get(stack_name=stack)
        rest_api = stack_ref.get_output(name=f"api_gateway---{resource_name}")
        return apigateway.RestApi.get(resource_name=resource_name, id=rest_api["id"])
